@@ -1,6 +1,7 @@
 /*
   Copyright (c) 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
   Copyright (c) 2011 Rodrigo Belem <rclbelem@gmail.com>
+  Copyright (c) 2019 Nate Graham <nate@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -23,6 +24,7 @@
 
 #include <QVariant>
 #include <QComboBox>
+#include <QLabel>
 #include <QProgressBar>
 #include <QPushButton>
 #ifdef SAMBA_INSTALL
@@ -46,18 +48,6 @@ public:
     virtual ~SambaUserSharePlugin();
     virtual void applyChanges();
 
-private Q_SLOTS:
-    void load();
-    void toggleShareStatus(bool checked);
-    void checkShareName(const QString &name);
-#ifdef SAMBA_INSTALL
-    void installSamba();
-    void packageInstall(PackageKit::Transaction::Info info,
-                        const QString &packageId,
-                        const QString &summary);
-    void packageFinished(PackageKit::Transaction::Exit status, uint runtime);
-#endif // SAMBA_INSTALL
-
 private:
     QString m_url;
     KSambaShareData shareData;
@@ -66,6 +56,7 @@ private:
     QWidget *m_failedSambaWidgets;
     QWidget *m_installSambaWidgets;
     QWidget *m_shareWidgets;
+    QLabel  *m_sambaStatusMessage;
     QProgressBar *m_installProgress;
     QPushButton *m_installSambaButton;
 
@@ -73,6 +64,14 @@ private:
     void setupViews();
     QStringList getUsersList();
     QString getNewShareName();
+    void load();
+    void toggleShareStatus(bool checked);
+    void checkShareName(const QString &name);
+#ifdef SAMBA_INSTALL
+    void installSamba();
+    void packageFinished(PackageKit::Transaction::Exit status, uint runtime);
+#endif // SAMBA_INSTALL
+
 
 };
 
